MisRepARMA-internal: Internal MisRepARMA functions

MisRepARMA-internalR Documentation

Internal MisRepARMA functions

Description

Internal MisRepARMA functions not intended to be called directly by the user.

Usage

estimate(data, tol, p_AR, q_MA, covars = NULL, misReport = "U")
estimate_bayes(data, p_AR, q_MA, covars = NULL, misReport = "U",
               n_chains = 3, n_iter = 2000, n_burnin = 500, n_thin = 1,
               q_prior_a = NULL, q_prior_b = NULL,
               w_prior_a = 1, w_prior_b = 1,
               q_init = NULL, w_init = NULL)
ran.genf(data, n, ran.args)
## S3 method for class 'fitMisRepARMA'
summary(object, ...)
## S3 method for class 'fitMisRepARMA'
print.summary(x, ...)

Arguments

data

numeric vector of observed time series values.

tol

convergence tolerance for the EM algorithm.

p_AR

order of the AR part.

q_MA

order of the MA part.

covars

optional matrix of covariates.

misReport

"U" for underreporting, "O" for overreporting.

n_chains

number of MCMC chains.

n_iter

total MCMC iterations per chain.

n_burnin

burn-in iterations to discard.

n_thin

thinning interval.

q_prior_a

first shape parameter of a Beta prior for q (currently unused; reserved for future use). Default NULL.

q_prior_b

second shape parameter of a Beta prior for q. Default NULL.

w_prior_a

first shape parameter of the Beta prior for \omega: \omega \sim \mathrm{Beta}(a, b). Default 1 (uniform prior).

w_prior_b

second shape parameter of the Beta prior for \omega. Default 1.

q_init

optional starting value for q (MCMC initialisation).

w_init

optional starting value for \omega (MCMC initialisation).

n

length of the simulated series (for ran.genf).

ran.args

list of simulation arguments (for ran.genf).

object

object of class fitMisRepARMA.

x

object of class summary.fitMisRepARMA.

...

further arguments (currently unused).

Details

estimate implements the frequentist iterative EM algorithm.

estimate_bayes implements Bayesian MCMC estimation via JAGS, called internally by fitMisRepARMA when method = "bayes".

ran.genf generates synthetic replicates for the bootstrap.

summary.fitMisRepARMA and print.summary.fitMisRepARMA provide formatted summaries for both frequentist and Bayesian fits.

See Also

MisRepARMA-package, fitMisRepARMA, reconstruct


MisRepARMA documentation built on June 7, 2026, 5:06 p.m.