| MisRepARMA-internal | R Documentation |
Internal MisRepARMA functions not intended to be called directly by the user.
estimate(data, tol, p_AR, q_MA, covars = NULL, misReport = "U")
estimate_bayes(data, p_AR, q_MA, covars = NULL, misReport = "U",
n_chains = 3, n_iter = 2000, n_burnin = 500, n_thin = 1,
q_prior_a = NULL, q_prior_b = NULL,
w_prior_a = 1, w_prior_b = 1,
q_init = NULL, w_init = NULL)
ran.genf(data, n, ran.args)
## S3 method for class 'fitMisRepARMA'
summary(object, ...)
## S3 method for class 'fitMisRepARMA'
print.summary(x, ...)
data |
numeric vector of observed time series values. |
tol |
convergence tolerance for the EM algorithm. |
p_AR |
order of the AR part. |
q_MA |
order of the MA part. |
covars |
optional matrix of covariates. |
misReport |
|
n_chains |
number of MCMC chains. |
n_iter |
total MCMC iterations per chain. |
n_burnin |
burn-in iterations to discard. |
n_thin |
thinning interval. |
q_prior_a |
first shape parameter of a Beta prior for |
q_prior_b |
second shape parameter of a Beta prior for |
w_prior_a |
first shape parameter of the Beta prior for
|
w_prior_b |
second shape parameter of the Beta prior for
|
q_init |
optional starting value for |
w_init |
optional starting value for |
n |
length of the simulated series (for |
ran.args |
list of simulation arguments (for |
object |
object of class |
x |
object of class |
... |
further arguments (currently unused). |
estimate implements the frequentist iterative EM algorithm.
estimate_bayes implements Bayesian MCMC estimation via JAGS,
called internally by fitMisRepARMA when
method = "bayes".
ran.genf generates synthetic replicates for the bootstrap.
summary.fitMisRepARMA and print.summary.fitMisRepARMA
provide formatted summaries for both frequentist and Bayesian fits.
MisRepARMA-package, fitMisRepARMA,
reconstruct
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.